/*
 * Copyright 2016-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.onosproject.nemo.model.operation.action.definitions;

import static com.google.common.base.MoreObjects.toStringHelper;

import java.util.Objects;

import org.onosproject.nemo.model.common.ActionName;

/**
 * The key to action definition.
 */
public class ActionDefinitionKey {

    private final ActionName actionName;

    /**
     * Creates an action definition key from a given action name.
     *
     * @param actionName the action name
     */
    public ActionDefinitionKey(ActionName actionName) {
        this.actionName = actionName;
    }

    /**
     * Creates a copy from a given action definition key.
     *
     * @param key the action definition key
     */
    public ActionDefinitionKey(ActionDefinitionKey key) {
        actionName = key.actionName;
    }

    /**
     * Returns the action name of this instance.
     *
     * @return the action name
     */
    public ActionName getActionName() {
        return actionName;
    }

    @Override
    public int hashCode() {
        return actionName.hashCode();
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj == null) {
            return false;
        }
        if (getClass() != obj.getClass()) {
            return false;
        }
        ActionDefinitionKey other = (ActionDefinitionKey) obj;
        return Objects.equals(actionName, other.actionName);
    }

    @Override
    public String toString() {
        return toStringHelper(this)
                .add("actionName", actionName)
                .toString();
    }
}