/*
 * Copyright 2016-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.onosproject.nemo.model.operation.action.instance.parameter.values;

import java.util.Objects;

import static com.google.common.base.MoreObjects.toStringHelper;

/**
 * String value key.
 */
public class StringValueKey {

    private final String value;
    private final long order;

    /**
     * Creates a string value key from the given order and value.
     *
     * @param order the order
     * @param value the value
     */
    public StringValueKey(long order, String value) {
        this.order = order;
        this.value = value;
    }

    /**
     * Creates a copy from Source Object.
     *
     * @param source Source object
     */
    public StringValueKey(StringValueKey source) {
        this.value = source.value;
        this.order = source.order;
    }

    /**
     * Returns the value of the instance.
     *
     * @return the value
     */
    public String getValue() {
        return value;
    }

    /**
     * Returns order of the instance.
     *
     * @return the order
     */
    public long getOrder() {
        return order;
    }

    @Override
    public int hashCode() {
        return Objects.hash(order, value);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj == null) {
            return false;
        }
        if (getClass() != obj.getClass()) {
            return false;
        }
        StringValueKey other = (StringValueKey) obj;
        return Objects.equals(value, other.value) &&
                Objects.equals(order, other.order);
    }

    @Override
    public String toString() {
        return toStringHelper(this)
                .add("order", order)
                .add("value", value)
                .toString();
    }
}