/*
 * Copyright 2016-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.onosproject.nemo.model.intent;

import static junit.framework.Assert.assertEquals;

import org.junit.Test;
import org.onosproject.nemo.model.common.UserId;

import com.google.common.testing.EqualsTester;

/**
 * Unit tests for {@link LanguageStyleNemoRequestInputBuilder}.
 */
public class LanguageStyleNemoRequestInputBuilderTest {

    private static final String ID = "00000000-0000-0000-0000-000000000000";
    private static final String OTHER_ID = "00000000-0000-0000-0000-000000000001";
    private static final String STATEMENT = "SomeStatement";
    private static final String OTHER_STATEMENT= "OtherStatement";
    private static final String ID_ERROR_MSG = "id not set";
    private static final String STATEMENT_ERROR_MSG = "statement not set";
    private static final String AUGMENTATION_ERROR_MSG = "augmentation not equal";

    private UserId userID;
    private UserId otherID;
    private LanguageStyleNemoRequestInput listParam;
    private LanguageStyleNemoRequestInput def;
    private LanguageStyleNemoRequestInput copy;
    private LanguageStyleNemoRequestInput diff;

    @Test
    public void buildLanguageStyleNemoRequestInputWithUserID() {
        userID = new UserId(ID);
        listParam = new LanguageStyleNemoRequestInputBuilder()
                .userId(userID)
                .nemoStatement(STATEMENT)
                .build();
        def = new LanguageStyleNemoRequestInputBuilder()
                .userId(userID)
                .nemoStatement(STATEMENT)
                .addAugmentation(LanguageStyleNemoRequestInput.class, listParam)
                .build();
        def = new LanguageStyleNemoRequestInputBuilder(def)
                .addAugmentation(LanguageStyleNemoRequestInput.class, null)
                .build();
        assertEquals(ID_ERROR_MSG, userID, def.getUserId());
        assertEquals(STATEMENT_ERROR_MSG, STATEMENT, def.getNemoStatement());
        assertEquals(AUGMENTATION_ERROR_MSG, listParam, def);
    }

    @Test
    public void fromLanguageStyleNemoRequestInput() {
        userID = new UserId(ID);
        def = new LanguageStyleNemoRequestInputBuilder()
                .userId(userID)
                .nemoStatement(STATEMENT)
                .build();
        copy = new LanguageStyleNemoRequestInputBuilder(def).build();
        assertEquals(ID_ERROR_MSG, userID, copy.getUserId());
        assertEquals(STATEMENT_ERROR_MSG, STATEMENT, copy.getNemoStatement());
    }

    @Test
    public void equality() {
        userID = new UserId(ID);
        def = new LanguageStyleNemoRequestInputBuilder()
                .userId(userID)
                .nemoStatement(STATEMENT)
                .build();
        copy = new LanguageStyleNemoRequestInputBuilder(def)
                .build();
        otherID = new UserId(OTHER_ID);
        diff = new LanguageStyleNemoRequestInputBuilder()
                .userId(otherID)
                .nemoStatement(OTHER_STATEMENT)
                .build();
        new EqualsTester()
                .addEqualityGroup(def, copy)
                .addEqualityGroup(diff)
                .testEquals();
    }
}