/*
 * Copyright 2016-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.onosproject.nemo.model.user.roles;

import com.google.common.testing.EqualsTester;
import org.junit.Test;
import org.onosproject.nemo.model.common.UserRoleName;
import org.onosproject.nemo.model.user.roles.UserRoleKey;

import static org.junit.Assert.assertEquals;

/**
 * Unit tests for {@link UserRoleKey}.
 */
public class UserRoleKeyTest {

    private static final String NAME = "SomeName";
    private static final String OTHER = "OtherName";

    private UserRoleKey key;
    private UserRoleKey copy;
    private UserRoleKey diff;

    @Test
    public void fromUserRoleName() {
        key = new UserRoleKey(new UserRoleName(NAME));
        assertEquals("name not set", NAME, key.getRoleName().getValue());
    }

    @Test
    public void copyConstructor() {
        key = new UserRoleKey(new UserRoleName(NAME));
        copy = new UserRoleKey(key);
        new EqualsTester()
                .addEqualityGroup(key, copy)
                .testEquals();
    }

    @Test
    public void equality() {
        key = new UserRoleKey(new UserRoleName(NAME));
        copy = new UserRoleKey(new UserRoleName(NAME));
        diff = new UserRoleKey(new UserRoleName(OTHER));
        new EqualsTester()
                .addEqualityGroup(key, copy)
                .addEqualityGroup(diff)
                .testEquals();
    }
}